==> libraryTtc-1.0.0-sources.jar: ai/botbrain/ttcloud/sdk/TsdConstant.java <==
package ai.botbrain.ttcloud.sdk;

import ai.botbrain.ttcloud.api.TtCloudManager;

/**
 * Description：
 * Creator: Created by peter.
 * Date: 17/3/21.
 */
public class TsdConstant {
    private static final String BASE_URL = TtCloudManager.DEBUG ? "http://test.bot.firedata.cc" : "https://ttc.botbrain.ai";

    public static final String PRE_USER_ID = "pre_user_id";
    public static final String PRE_USER_NAME = "pre_user_name";
    public static final String PRE_USER_AVATAR = "pre_user_avatar";
    public static final String PRE_USER_NICK_NAME = "pre_user_nick_name";

    //public static final String TYPE_AD = "ad";
    public static final String TYPE_QQ = "qq.e";
    public static final String TYPE_360 = "360";

    public static final String EXTRA_IID = "extra_iid";
    public static final String EXTRA_COLUMN_ID = "extra_column_id";

    public static final String URL_JS = TsdConstant.BASE_URL + "/inject/h5_video_player_inject.js";

    public static final String PREF_RECOMMENDED_HOME = "pref_recommended_Home";
    public static final String PREF_IS_FIRST_LAUNCH = "pref_is_first_launcher";
    public static final String PREF_GRAPHIC = "pref_graphic";
    public static final String PREF_CHANNEL = "pref_channel";

    public static final String HTTP_COUNT = "count";
    public static final String HTTP_GET = "get";

    public static final int REQUEST_COUNT_CONTENT_LIST = 10;

    public static final String STR_ZERO = "0";

    public static final String ACTION_CLICK = "click";
    public static final String ACTION_AD_ERROR = "aderror";
    public static final String ACTION_DISLIKE = "dislike";

    public static final String PARAM_PLATFORM = "android";

    public static final int ONCE_HTTP_COUNT = 6;

    public static final int CROSSFADEDURATION = 250;


}

==> libraryTtc-1.0.2-sources.jar: ai/botbrain/ttcloud/sdk/TsdConstant.java <==
package ai.botbrain.ttcloud.sdk;

import ai.botbrain.ttcloud.api.TtCloudManager;

/**
 * Description：
 * Creator: Created by peter.
 * Date: 17/3/21.
 */
public class TsdConstant {
    private static final String BASE_URL = TtCloudManager.DEBUG ? "http://test.bot.firedata.cc" : "https://ttc.botbrain.ai";

    public static final String PRE_THEME = "pre_theme";

    public static final String FEED_TYPE = "arg_type_video";

    public static final String TYPE_ARTICLE = "article";
    public static final String TYPE_VIDEO = "video";

    public static final String PRE_USER_ID = "pre_user_id";
    public static final String PRE_USER_NAME = "pre_user_name";
    public static final String PRE_USER_AVATAR = "pre_user_avatar";
    public static final String PRE_USER_NICK_NAME = "pre_user_nick_name";

    //public static final String TYPE_AD = "ad";
    public static final String TYPE_QQ = "qq.e";
    public static final String TYPE_360 = "360";

    public static final String EXTRA_IID = "extra_iid";
    public static final String EXTRA_COLUMN_ID = "extra_column_id";

    public static final String URL_JS = TsdConstant.BASE_URL + "/inject/h5_video_player_inject.js";

    public static final String PREF_RECOMMENDED_HOME = "pref_recommended_Home";
    public static final String PREF_IS_FIRST_LAUNCH = "pref_is_first_launcher";
    public static final String PREF_GRAPHIC = "pref_graphic";
    public static final String PREF_CHANNEL = "pref_channel";

    public static final String HTTP_COUNT = "count";
    public static final String HTTP_GET = "get";

    public static final int REQUEST_COUNT_CONTENT_LIST = 10;

    public static final String STR_ZERO = "0";

    public static final String ACTION_CLICK = "click";
    public static final String ACTION_AD_ERROR = "aderror";
    public static final String ACTION_DISLIKE = "dislike";

    public static final String PARAM_PLATFORM = "android";

    public static final int ONCE_HTTP_COUNT = 6;

    public static final int CROSSFADEDURATION = 250;


}
